The gCube System - the gCube messaging producer
------------------------------------------------------------

This work has been partially supported by the following European projects: DILIGENT (FP6-2003-IST-2), 
D4Science (FP7-INFRA-2007-1.2.2), D4Science-II (FP7-INFRA-2008-1.2.2), iMarine (FP7-INFRASTRUCTURES-2011-2), 
and EUBrazilOpenBio (FP7-ICT-2011-EU-Brazil).


Authors
-------

* Andrea Manzi (andrea.manzi@cern.ch), CERN, Geneva 
 
Version and Release Date
------------------------
v. 1.1.0 (07-09-12)
    
 
Description
-----------


Download information
--------------------

Source code is available from SVN:
${scm.url} 


Documentation 
-------------

https://gcube.wiki.gcube-system.org/gcube/index.php/Messaging_Infrastructure#Local_Producer

Licensing
---------

This software is licensed under the terms you may find in the file named "LICENSE" 
in this directory.



