% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{\%+\%}
\alias{\%+\%}
\title{short for `paste0()`}
\usage{
a \%+\% b
}
\arguments{
\item{a}{string}

\item{b}{string}
}
\value{
string
}
\description{
short for `paste0()`
}
